@@ -28,7 +28,10 @@ class MultiAgentEpisode:
         episode_id (int): Unique id identifying this trajectory.
         agent_rewards (dict): Summed rewards broken down by agent.
         custom_metrics (dict): Dict where the you can add custom metrics.
-        user_data (dict): Dict that you can use for temporary storage.
+        user_data (dict): Dict that you can use for temporary storage. E.g.
+            in between two custom callbacks referring to the same episode.
+        hist_data (dict): Dict mapping str keys to List[float] for storage of
+            per-timestep float data throughout the episode.
 
     Use case 1: Model-based rollouts in multi-agent:
         A custom compute_actions() function in a policy can inspect the
@@ -64,6 +67,7 @@ class MultiAgentEpisode:
         self.custom_metrics: Dict[str, float] = {}
         self.user_data: Dict[str, Any] = {}
         self.hist_data: Dict[str, List[float]] = {}
+        self.media: Dict[str, Any] = {}
         self._policies: Dict[PolicyID, Policy] = policies
         self._policy_mapping_fn: Callable[[AgentID], PolicyID] = \
             policy_mapping_fn
