@@ -19,6 +19,6 @@ import ray.state
 print("import: 'ray.worker'")
 import ray.worker
 
-print("import: 'ray.metrics_agent'")
-import ray.metrics_agent
+print("import: 'ray._private.metrics_agent'")
+import ray._private.metrics_agent
 
